@@ -8,6 +8,7 @@ from shutil import move
 from qbittorrentapi import Client
 import time
 import datetime
+import shutil
 
 
 def get_newhash(qbinfo):
@@ -193,6 +194,112 @@ def seedmachine_single(pathinfo,sites,pathyaml,basic,qbinfo,imgdata,hashlist):
     logger.info('路径'+pathinfo.path+'下资源已全部发布完毕')
     return log_error,log_succ
 
+
+#发布剩余合集
+def seedmachine_rest(pathinfo,sites,pathyaml,basic,qbinfo,imgdata,hashlist):
+    
+    #把没发布的集数转移到新建文件夹内
+    log_error=''
+    log_succ=''
+    logstr=''
+    for siteitem in sites:
+        #发布过此集的站点略过
+        if sites[siteitem].enable!=1 or ( eval('pathinfo.'+siteitem+'_max_done==10000')):
+            continue
+        #收集需要发布的合集
+        eps=[]
+        for pathep in pathinfo.eps:
+            if  not eval('pathep in pathinfo.'+siteitem+'_done'):
+                eps.append(int (pathep))
+        if len(eps)<=0:
+            logger.info('正在'+siteitem+'站点发布路径'+pathinfo.path+'下无未发布分集,已跳过')
+            continue
+        #1.将没有发布过的资源移到新路径path_new
+        #新建文件夹
+        path_new=os.path.join(pathinfo.path,os.path.basename(pathinfo.path))
+        try:
+            os.mkdir(path_new)
+        except Exception as r:
+            logger.warning('新建文件夹发生错误,错误信息: %s' %(r))  
+            log_error=log_error+'路径'+pathinfo.path+'新建同名子文件夹发生错误\n'
+            continue
+        ls = os.listdir(pathinfo.path)
+        filepath=''
+        ls = os.listdir(pathinfo.path)
+        for i in ls:
+            c_path=os.path.join(pathinfo.path, i)
+            if (os.path.isdir(c_path)) or (i.startswith('.')) or (not(  os.path.splitext(i)[1].lower()== ('.mp4') or os.path.splitext(i)[1].lower()== ('.mkv')  or os.path.splitext(i)[1].lower()== ('.avi') or os.path.splitext(i)[1].lower()== ('.ts')    )):
+                continue
+            if int(findnum(i)[0]) in eps:
+                shutil.move(c_path, path_new) 
+        
+        #2.将path_new按照合集发布
+        logger.info('正在'+siteitem+'站点发布路径'+pathinfo.path+'下没发布过的资源合集，分别为：'+str(eps))
+        
+        errornum=0
+        succnum=0
+        siteitem=sites[siteitem]
+        #获取file全部信息
+        file1=mediafile(path_new,pathinfo,basic,imgdata)
+        logger.info('正在抓取资源信息,请稍后...')
+        file1.getfullinfo()
+        if not pathinfo.imdb_url=='' and pathyaml['imdb_url']==None:
+            pathyaml['imdb_url']=pathinfo.imdb_url
+        upload_success=False
+        uploadtime=0
+        #用模板获取mediainfo
+        file1.updatemediainfo(siteitem.mediainfo_template_file)
+        while upload_success==False and uploadtime<3:
+            uploadtime=uploadtime+1
+            logger.info('第'+str(uploadtime)+'次尝试发布')
+            print("正在准备登录"+siteitem.sitename)
+            upload_success,logstr=auto_upload(siteitem,file1,basic['record_path'],qbinfo,basic,hashlist)
+            if not upload_success:
+                logger.warning(siteitem.sitename+'第'+str(uploadtime)+'次发布任务失败')
+                logger.warning(logstr)
+                #file1.mktorrent()
+        if not upload_success:
+            logger.warning(siteitem.sitename+'发布任务失败，本站暂停发种')
+            siteitem.enable=0
+            errornum=errornum+1
+            log_error=log_error+str(errornum)+':\t'+siteitem.sitename+'  \t'+logstr+'\n'
+            logger.warning(logstr)
+        elif '已存在' in  logstr:
+            errornum=errornum+1
+            log_error=log_error+str(errornum)+':\t'+siteitem.sitename+'   \t'+logstr+'\n'
+            logger.warning(logstr)
+            #记录已发布的种子
+            for epitem in eps:
+                exec('pathinfo.'+siteitem.sitename+'_done.append('+str(epitem)+')')
+            exec('pathinfo.'+siteitem.sitename+'_done=list(set('+'pathinfo.'+siteitem.sitename+'_done'+'))')
+            exec('pathinfo.'+siteitem.sitename+'_done.sort()')
+            exec('pathyaml["'+siteitem.sitename+'"]=",".join([str(i) for i in pathinfo.'+siteitem.sitename+'_done])')
+        else:
+            succnum=succnum+1
+            log_succ=log_succ+str(succnum)+':\t'+siteitem.sitename+'   \t'+logstr+'\n'
+            logger.info(logstr)
+            #记录已发布的种子
+            for epitem in eps:
+                exec('pathinfo.'+siteitem.sitename+'_done.append('+str(epitem)+')')
+            exec('pathinfo.'+siteitem.sitename+'_done=list(set('+'pathinfo.'+siteitem.sitename+'_done'+'))')
+            exec('pathinfo.'+siteitem.sitename+'_done.sort()')
+            exec('pathyaml["'+siteitem.sitename+'"]=",".join([str(i) for i in pathinfo.'+siteitem.sitename+'_done])')
+            #deletetorrent(basic['screenshot_path'])
+        #a=input('check')
+            
+        del(file1)  
+        logger.info(siteitem.sitename+'站点,路径'+pathinfo.path+'下资源合集发布完毕，分别为：'+str(eps))
+        #3.把文件返回原位
+        ls = os.listdir(path_new)
+        for i in ls:
+            c_path=os.path.join(path_new, i)
+            if (os.path.isdir(c_path)) or (i.startswith('.')) or (not(  os.path.splitext(i)[1].lower()== ('.mp4') or os.path.splitext(i)[1].lower()== ('.mkv')  or os.path.splitext(i)[1].lower()== ('.avi') or os.path.splitext(i)[1].lower()== ('.ts')    )):
+                continue
+            shutil.move(c_path, pathinfo.path) 
+        #4.删除path_new文件夹
+        shutil.rmtree(path_new)
+    return log_error,log_succ
+    
 #发布合集
 def seedmachine(pathinfo,sites,pathyaml,basic,qbinfo,imgdata,hashlist):
     '''
@@ -223,12 +330,13 @@ def seedmachine(pathinfo,sites,pathyaml,basic,qbinfo,imgdata,hashlist):
 
     #获取file全部信息
     file1=mediafile(pathinfo.path,pathinfo,basic,imgdata)
+    logger.info('正在抓取资源信息,请稍后...')
+    file1.getfullinfo()
     if not pathinfo.imdb_url=='' and pathyaml['imdb_url']==None:
         pathyaml['imdb_url']=pathinfo.imdb_url
 
     logger.info('正在发布路径'+pathinfo.path+'下资源')
-    logger.info('正在抓取资源信息,请稍后...')
-    file1.getfullinfo()
+    
 
     for siteitem in site_upload:
         if siteitem.enable==0:
@@ -263,7 +371,8 @@ def seedmachine(pathinfo,sites,pathyaml,basic,qbinfo,imgdata,hashlist):
             #记录已发布的种子
             for epitem in pathinfo.eps:
                 exec('pathinfo.'+siteitem.sitename+'_done.append('+str(epitem)+')')
-            exec('pathinfo.'+siteitem.sitename+'_done.append(-1)')
+            if pathinfo.complete==1:
+                exec('pathinfo.'+siteitem.sitename+'_done.append(-1)')
             exec('pathinfo.'+siteitem.sitename+'_done=list(set('+'pathinfo.'+siteitem.sitename+'_done'+'))')
             exec('pathinfo.'+siteitem.sitename+'_done.sort()')
             exec('pathyaml["'+siteitem.sitename+'"]=",".join([str(i) for i in pathinfo.'+siteitem.sitename+'_done])')
@@ -274,7 +383,8 @@ def seedmachine(pathinfo,sites,pathyaml,basic,qbinfo,imgdata,hashlist):
             #记录已发布的种子
             for epitem in pathinfo.eps:
                 exec('pathinfo.'+siteitem.sitename+'_done.append('+str(epitem)+')')
-            exec('pathinfo.'+siteitem.sitename+'_done.append(-1)')
+            if pathinfo.complete==1:
+                exec('pathinfo.'+siteitem.sitename+'_done.append(-1)')
             exec('pathinfo.'+siteitem.sitename+'_done=list(set('+'pathinfo.'+siteitem.sitename+'_done'+'))')
             exec('pathinfo.'+siteitem.sitename+'_done.sort()')
             exec('pathyaml["'+siteitem.sitename+'"]=",".join([str(i) for i in pathinfo.'+siteitem.sitename+'_done])')
@@ -297,6 +407,8 @@ def start_machine(pathlist,sites,yamlinfo):
             continue
         if (path.type=='anime' or path.type=='tv') and path.collection==0:
             log_error,log_succ=seedmachine_single(path,sites,yamlinfo['path info'][path.pathid],yamlinfo['basic'],yamlinfo['qbinfo'],yamlinfo['image hosting'],hashlist)
+        elif (path.type=='anime' or path.type=='tv') and path.collection==2:
+            log_error,log_succ=seedmachine_rest(path,sites,yamlinfo['path info'][path.pathid],yamlinfo['basic'],yamlinfo['qbinfo'],yamlinfo['image hosting'],hashlist)
         else:
             log_error,log_succ=seedmachine(path,sites,yamlinfo['path info'][path.pathid],yamlinfo['basic'],yamlinfo['qbinfo'],yamlinfo['image hosting'],hashlist)
         write_yaml(yamlinfo)
